@@ -34,7 +34,21 @@ class KinesisDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-logs-destinations.KinesisDestination",
 ):
-    '''Use a Kinesis stream as the destination for a log subscription.'''
+    '''Use a Kinesis stream as the destination for a log subscription.
+
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_kinesis as kinesis
+        import aws_cdk.aws_logs_destinations as logs_destinations
+        
+        # stream is of type Stream
+        
+        kinesis_destination = logs_destinations.KinesisDestination(stream)
+    '''
 
     def __init__(self, stream: aws_cdk.aws_kinesis.IStream) -> None:
         '''
@@ -68,7 +82,21 @@ class LambdaDestination(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-logs-destinations.LambdaDestination",
 ):
-    '''Use a Lambda Function as the destination for a log subscription.'''
+    '''Use a Lambda Function as the destination for a log subscription.
+
+    Example::
+
+        import aws_cdk.aws_logs_destinations as destinations
+        # fn is of type Function
+        # log_group is of type LogGroup
+        
+        
+        logs.SubscriptionFilter(self, "Subscription",
+            log_group=log_group,
+            destination=destinations.LambdaDestination(fn),
+            filter_pattern=logs.FilterPattern.all_terms("ERROR", "MainThread")
+        )
+    '''
 
     def __init__(
         self,
@@ -120,6 +148,18 @@ class LambdaDestinationOptions:
         '''Options that may be provided to LambdaDestination.
 
         :param add_permissions: Whether or not to add Lambda Permissions. Default: true
+
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_logs_destinations as logs_destinations
+            
+            lambda_destination_options = logs_destinations.LambdaDestinationOptions(
+                add_permissions=False
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if add_permissions is not None:
